@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-10-17 14:03:16
+@LastEditTime: 2022-10-21 11:17:40
 @LastEditors: HuangJianYi
 @Description: 活动模块
 """
@@ -74,11 +74,12 @@ class AddActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.add_act_info(app_id, act_name, act_type, theme_id, share_desc_json, rule_desc_json, close_word)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.add.value, model_name="act_info_tb", old_detail=None, update_detail=invoke_result_data.data, title=act_name)
+        self.create_operation_log(operation_type=OperationType.add.value, model_name="act_info_tb", old_detail=None, update_detail=invoke_result_data.data, title= title_prefix + act_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -158,11 +159,12 @@ class UpdateActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info(app_id, act_id, act_name, theme_id, is_share, share_desc_json, is_rule, rule_desc_json, is_release, start_date, end_date, is_black, refund_count, join_ways, is_fictitious, close_word, store_url, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, is_visit_store)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.update.value, model_name="act_info_tb", old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=act_name)
+        self.create_operation_log(operation_type=OperationType.update.value, model_name="act_info_tb", old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=title_prefix + act_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -257,11 +259,12 @@ class DeleteActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_info_tb", title=invoke_result_data.data["act_name"])
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_info_tb", title= title_prefix + invoke_result_data.data["act_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -286,11 +289,12 @@ class ReviewActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.update_act_info_status(app_id, act_id, 0)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_info_tb", title=invoke_result_data.data["act_name"])
+        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_info_tb", title= title_prefix + invoke_result_data.data["act_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -317,12 +321,13 @@ class ReleaseActInfoHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "活动；"
         act_base_model = ActBaseModel(context=self)
         invoke_result_data = act_base_model.release_act_info(app_id, act_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
-        self.create_operation_log(operation_type=operation_type, model_name="act_info_tb", title=invoke_result_data.data["act_name"])
+        self.create_operation_log(operation_type=operation_type, model_name="act_info_tb", title= title_prefix + invoke_result_data.data["act_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
