@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-10-17 14:16:15
+@LastEditTime: 2022-10-21 11:29:01
 @LastEditors: HuangJianYi
 @Description: 小活动模块（机台）
 """
@@ -82,15 +82,21 @@ class SaveActModuleHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        default_prefix = ""
+        if business_type == 1:
+            default_prefix = "机台；"
+        elif business_type == 2:
+            default_prefix = "活动；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
         module_base_model = ModuleBaseModel(context=self)
         invoke_result_data = module_base_model.save_act_module(app_id, act_id, module_id, module_name, module_sub_name, start_date, end_date, module_pic, module_desc, price, price_gear_id, ip_id, join_ways, is_fictitious, sort_index, is_release, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2, business_type)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=module_name)
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title= title_prefix + module_name)
         else:
-            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=module_name)
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + module_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -198,7 +204,13 @@ class DeleteActModuleHandler(ClientBaseHandler):
         invoke_result_data = module_base_model.update_act_module_status(app_id, module_id, 1)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_module_tb", title=invoke_result_data.data["module_name"])
+        default_prefix = ""
+        if invoke_result_data.data["business_type"] == 1:
+            default_prefix = "机台；"
+        elif invoke_result_data.data["business_type"] == 2:
+            default_prefix = "活动；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_module_tb", title= title_prefix + invoke_result_data.data["module_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
@@ -228,7 +240,13 @@ class ReviewActModuleHandler(ClientBaseHandler):
         invoke_result_data = module_base_model.update_act_module_status(app_id, module_id, 0)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_module_tb", title=invoke_result_data.data["module_name"])
+        default_prefix = ""
+        if invoke_result_data.data["business_type"] == 1:
+            default_prefix = "机台；"
+        elif invoke_result_data.data["business_type"] == 2:
+            default_prefix = "活动；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
+        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_module_tb", title= title_prefix + invoke_result_data.data["module_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
@@ -261,7 +279,13 @@ class ReleaseActModuleHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
-        self.create_operation_log(operation_type=operation_type, model_name="act_module_tb", title=invoke_result_data.data["module_name"])
+        default_prefix = ""
+        if invoke_result_data.data["business_type"] == 1:
+            default_prefix = "机台；"
+        elif invoke_result_data.data["business_type"] == 2:
+            default_prefix = "活动；"
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else default_prefix
+        self.create_operation_log(operation_type=operation_type, model_name="act_module_tb", title= title_prefix + invoke_result_data.data["module_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
