@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-09 14:11:52
-@LastEditTime: 2022-10-17 18:59:40
+@LastEditTime: 2022-10-21 11:37:15
 @LastEditors: HuangJianYi
 @Description: 订单模块
 """
@@ -298,12 +298,12 @@ class ImportPrizeOrderHandler(ClientBaseHandler):
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
-        menu_name = invoke_result_data.data["menu_name"] if invoke_result_data.data.__contains__("menu_name") else "发货列表"
+        operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "发货列表"
         order_base_model = OrderBaseModel(context=self)
         invoke_result_data = order_base_model.import_prize_order(app_id, act_id, content_type, content, ref_head_name, prize_roster_sub_table)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.import_data.value, model_name="prize_order_tb", title=menu_name)
+        self.create_operation_log(operation_type=OperationType.import_data.value, model_name="prize_order_tb", title=operate_title)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success ==False:
@@ -359,7 +359,7 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
-        menu_name = invoke_result_data.data["menu_name"] if invoke_result_data.data.__contains__("menu_name") else "发货列表"
+        operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "发货列表"
         prize_roster_sub_table = invoke_result_data.data["prize_roster_sub_table"] if invoke_result_data.data.__contains__("prize_roster_sub_table") else None
 
         order_base_model = OrderBaseModel(context=self)
@@ -379,7 +379,7 @@ class PrizeOrderExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(prize_order_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
-        self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_order_tb", title=menu_name)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_order_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data,ref_params):
@@ -475,7 +475,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
-        menu_name = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("menu_name") else "中奖记录列表"
+        operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "中奖记录列表"
 
         order_base_model = OrderBaseModel(context=self)
         prize_roster_list_dict = []
@@ -493,7 +493,7 @@ class PrizeRosterExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(prize_roster_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
-        self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_roster_tb", title=menu_name)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="prize_roster_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data, ref_params):
@@ -567,7 +567,7 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
-        menu_name = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("menu_name") else "支付订单列表"
+        operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "支付订单列表"
 
         if main_pay_order_no:
             condition += " and " if condition else ""
@@ -595,7 +595,7 @@ class TaoPayOrderExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(tao_pay_order_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
-        self.create_operation_log(operation_type=OperationType.export.value, model_name="tao_pay_order_tb", title=menu_name)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="tao_pay_order_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data, ref_params):
