@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 14:25:02
-@LastEditTime: 2022-10-17 14:34:07
+@LastEditTime: 2022-10-21 11:31:14
 @LastEditors: HuangJianYi
 @Description: 价格档位模块
 """
@@ -49,16 +49,16 @@ class SavePriceGearHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "价格档位；"
         price_base_model = PriceBaseModel(context=self)
         invoke_result_data = price_base_model.save_price_gear(app_id, act_id, price_gear_id, relation_type, price_gear_name, price_gear_pic, price, goods_id, sku_id, remark, sort_index)
         if invoke_result_data.success ==False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=price_gear_name)
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title= title_prefix + price_gear_name)
         else:
-            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=price_gear_name)
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + price_gear_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -119,7 +119,8 @@ class DeletePriceGearHandler(ClientBaseHandler):
         invoke_result_data = price_base_model.update_price_gear_status(app_id, act_id, price_gear_id, 1)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.delete.value, model_name="price_gear_tb", title=invoke_result_data.data["price_gear_name"])
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "价格档位；"
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="price_gear_tb", title= title_prefix + invoke_result_data.data["price_gear_name"])
         return self.response_json_success()
 
 
@@ -145,7 +146,8 @@ class ReviewPriceGearHandler(ClientBaseHandler):
         invoke_result_data = price_base_model.update_price_gear_status(app_id, act_id, price_gear_id, 0)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.review.value, model_name="price_gear_tb", title=invoke_result_data.data["price_gear_name"])
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "价格档位；"
+        self.create_operation_log(operation_type=OperationType.review.value, model_name="price_gear_tb", title= title_prefix + invoke_result_data.data["price_gear_name"])
         return self.response_json_success()
 
 
