@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2022-10-17 14:47:19
+@LastEditTime: 2022-10-21 11:36:45
 @LastEditors: HuangJianYi
 @Description: 奖品模块
 """
@@ -111,15 +111,16 @@ class SaveActPrizeHandler(ClientBaseHandler):
         if not invoke_result_data.data:
             invoke_result_data.data = {}
         prize_total = invoke_result_data.data["prize_total"] if invoke_result_data.data.__contains__("prize_total") else prize_total
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品；"
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.save_act_prize(app_id, act_id, module_id, prize_id, prize_name, prize_title, prize_pic, prize_detail_json, goods_id, goods_code, goods_code_list, goods_type, prize_type, prize_price, probability, chance, prize_limit, is_prize_notice, prize_total, is_surplus, lottery_type, tag_name, tag_id, is_sku, sku_json, sort_index, is_release, ascription_type, i1, i2, i3, i4, i5, s1, s2, s3, s4, s5, d1, d2)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if invoke_result_data.data["is_add"] == True:
             # 记录日志
-            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title=prize_name)
+            self.create_operation_log(operation_type=OperationType.add.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=None, update_detail=invoke_result_data.data["new"], title= title_prefix + prize_name)
         else:
-            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title=prize_name)
+            self.create_operation_log(operation_type=OperationType.update.value, model_name=invoke_result_data.data["new"].__str__(), old_detail=invoke_result_data.data["old"], update_detail=invoke_result_data.data["new"], title= title_prefix + prize_name)
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -188,11 +189,12 @@ class DeleteActPrizeHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品；"
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 1)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_prize_tb", title=invoke_result_data.data["prize_name"])
+        self.create_operation_log(operation_type=OperationType.delete.value, model_name="act_prize_tb", title= title_prefix + invoke_result_data.data["prize_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -218,11 +220,12 @@ class ReviewActPrizeHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品；"
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.update_act_prize_status(app_id, prize_id, 0)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_prize_tb", title=invoke_result_data.data["prize_name"])
+        self.create_operation_log(operation_type=OperationType.review.value, model_name="act_prize_tb", title= title_prefix + invoke_result_data.data["prize_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -250,12 +253,13 @@ class ReleaseActPrizeHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "奖品；"
         prize_base_model = PrizeBaseModel(context=self)
         invoke_result_data = prize_base_model.release_act_prize(app_id, prize_id, is_release)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         operation_type = OperationType.release.value if is_release == 1 else OperationType.un_release.value
-        self.create_operation_log(operation_type=operation_type, model_name="act_prize_tb", title=invoke_result_data.data["prize_name"])
+        self.create_operation_log(operation_type=operation_type, model_name="act_prize_tb", title= title_prefix + invoke_result_data.data["prize_name"])
         ref_params = {}
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
@@ -297,7 +301,8 @@ class ActPrizeExportHandler(ClientBaseHandler):
         params = invoke_result_data.data["params"] if invoke_result_data.data.__contains__("params") else []
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "create_date desc"
         field = invoke_result_data.data["field"] if invoke_result_data.data.__contains__("field") else "*"
-        menu_name = invoke_result_data.data["menu_name"] if invoke_result_data.data.__contains__("menu_name") else "奖品列表"
+        operate_title = invoke_result_data.data["operate_title"] if invoke_result_data.data.__contains__("operate_title") else "奖品列表"
+
 
         prize_base_model = PrizeBaseModel(context=self)
         act_prize_list_dict = []
@@ -315,7 +320,7 @@ class ActPrizeExportHandler(ClientBaseHandler):
         ref_params = {}
         result_data = self.business_process_executed(act_prize_list_dict, ref_params)
         resource_path = OSS2Helper.export_excel(result_data)
-        self.create_operation_log(operation_type=OperationType.export.value, model_name="act_prize_tb", title=menu_name)
+        self.create_operation_log(operation_type=OperationType.export.value, model_name="act_prize_tb", title=operate_title)
         return self.response_json_success(resource_path)
 
     def business_process_executed(self, result_data, ref_params):
