@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-11-16 13:44:20
-@LastEditTime: 2022-06-13 14:38:54
+@LastEditTime: 2022-11-18 17:00:37
 @LastEditors: HuangJianYi
 :description: 报表模块
 """
@@ -36,11 +36,13 @@ class StatReportListHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
+        orm_condition = invoke_result_data.data["orm_condition"] if invoke_result_data.data.__contains__("orm_condition") else None
+        orm_params = invoke_result_data.data["orm_params"] if invoke_result_data.data.__contains__("orm_params") else None
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index asc"
         is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else False
 
         stat_base_model = StatBaseModel(context=self)
-        stat_report_list = stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module)
+        stat_report_list = stat_base_model.get_stat_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module, orm_condition, orm_params)
         ref_params = {}
         stat_report_list = self.business_process_executed(stat_report_list, ref_params)
         return self.response_json_success(stat_report_list)
@@ -73,11 +75,13 @@ class TrendReportListHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
+        orm_condition = invoke_result_data.data["orm_condition"] if invoke_result_data.data.__contains__("orm_condition") else None
+        orm_params = invoke_result_data.data["orm_params"] if invoke_result_data.data.__contains__("orm_params") else None
         order_by = invoke_result_data.data["order_by"] if invoke_result_data.data.__contains__("order_by") else "sort_index asc"
         is_only_module = invoke_result_data.data["is_only_module"] if invoke_result_data.data.__contains__("is_only_module") else False
 
         stat_base_model = StatBaseModel(context=self)
-        trend_report_list = stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module)
+        trend_report_list = stat_base_model.get_trend_report_list(app_id, act_id, module_id, start_date, end_date, order_by, is_only_module, orm_condition, orm_params)
         ref_params = {}
         trend_report_list = self.business_process_executed(trend_report_list, ref_params)
         return self.response_json_success(trend_report_list)
