@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-10 10:05:38
-@LastEditTime: 2022-10-20 17:15:10
+@LastEditTime: 2022-10-27 14:22:00
 @LastEditors: HuangJianYi
 @Description: 任务模块
 """
@@ -63,7 +63,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         if not invoke_result_data.data:
             invoke_result_data.data = {}
-        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else ""
+        title_prefix = invoke_result_data.data["title_prefix"] if invoke_result_data.data.__contains__("title_prefix") else "任务；"
         operate_user_id = invoke_result_data.data["operate_user_id"] if invoke_result_data.data.__contains__("operate_user_id") else ""
         operate_user_name = invoke_result_data.data["operate_user_name"] if invoke_result_data.data.__contains__("operate_user_name") else ""
         operate_role_id = invoke_result_data.data["operate_role_id"] if invoke_result_data.data.__contains__("operate_role_id") else ""
@@ -82,7 +82,7 @@ class SaveTaskInfoHandler(ClientBaseHandler):
             sort_index = int(item["sort_index"]) if item.__contains__("sort_index") else 0
             is_release = int(item["is_release"]) if item.__contains__("is_release") else 0
             config_json = SevenHelper.json_dumps(item["config_json"]) if item.__contains__("config_json") else {}
-            title = title_prefix + ";" + task_name if title_prefix else task_name
+            title = title_prefix + task_name if title_prefix else task_name
             if "id" in item.keys():
                 task_info = task_info_model.get_entity_by_id(int(item["id"]))
                 if task_info:
