@@ -17,7 +17,7 @@ class CacheModel(BaseModel):
 
     def __init__(self, model_class, sub_table):
         """
-        :Description: 数据缓存业务模型,用于mysql数据同步到redis
+        :Description: 数据缓存业务模型,用于mysql数据同步到redis，dependency_cache_expire(依赖建缓存时间默认300分钟，普通缓存默认30分钟)
         :param model_class: 实体对象类
         :param sub_table: 分表标识
         :last_editors: HuangJianYi
@@ -122,7 +122,7 @@ class CacheModel(BaseModel):
         redis_init = self.__redis_init()
         dependency_date_value = redis_init.get(dependency_key)
         if not dependency_date_value:
-            redis_init.set(dependency_key,str(TimeHelper.get_now_format_time()),ex=config.get_value("dependency_cache_expire",60*60))
+            redis_init.set(dependency_key,str(TimeHelper.get_now_format_time()),ex=config.get_value("dependency_cache_expire",5*60*60))
         dependency_cache_key = self.get_dependency_cache_key(dependency_key,cache_key)
         redis_init.set(dependency_cache_key + "_savetime",str(TimeHelper.get_now_format_time()),ex=cache_expire)
         return redis_init.set(dependency_cache_key,JsonHelper.json_dumps(value),ex=cache_expire)
@@ -133,11 +133,14 @@ class CacheModel(BaseModel):
         :return: redis_cli
         :last_editors: HuangJianYi
         """
-        host = config.get_value("redis")["host"]
-        port = config.get_value("redis")["port"]
+        cache_redis = config.get_value("cache_redis")
+        if not cache_redis:
+            cache_redis = config.get_value("redis")
+        host = cache_redis["host"]
+        port = cache_redis["port"]
         if not db:
-            db = config.get_value("redis")["db"]
-        password = config.get_value("redis")["password"]
+            db = cache_redis["db"]
+        password = cache_redis["password"]
         redis_cli = RedisHelper.redis_init(host, port, db, password, decode_responses=decode_responses)
         return redis_cli
 
@@ -172,7 +175,7 @@ class CacheModel(BaseModel):
                 print(traceback.print_exc())
                 pass
 
-    def get_cache_list(self, where='', group_by='', order_by='', limit='', field="*", params=None,dependency_key='', cache_expire=600):
+    def get_cache_list(self, where='', group_by='', order_by='', limit='', field="*", params=None,dependency_key='', cache_expire=1800):
         """
         :Description: 根据条件获取列表
         :param where: 数据库查询条件语句
@@ -214,7 +217,7 @@ class CacheModel(BaseModel):
             self.set_dependency_cache(dependency_key,cache_key,cache_value,cache_expire)
             return self._BaseModel__row_entity_list(list_row)
 
-    def get_cache_page_list(self, field="*", page_index=0, page_size=20, where='', group_by='', order_by='', params=None, dependency_key='', cache_expire=600):
+    def get_cache_page_list(self, field="*", page_index=0, page_size=20, where='', group_by='', order_by='', params=None, dependency_key='', cache_expire=1800):
         """
         :Description: 分页获取数据
         :param field: 查询字段 
@@ -261,7 +264,7 @@ class CacheModel(BaseModel):
             self.set_dependency_cache(dependency_key,cache_key,page_list,cache_expire)
             return self._BaseModel__row_entity_list(page_list["data"]), row_count
 
-    def get_cache_entity(self, where='', group_by='', order_by='',  params=None, dependency_key='', cache_expire=600):
+    def get_cache_entity(self, where='', group_by='', order_by='',  params=None, dependency_key='', cache_expire=1800):
         """
         :Description: 根据条件获取实体对象
         :param where: 数据库查询条件语句
@@ -296,7 +299,7 @@ class CacheModel(BaseModel):
             self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return self._BaseModel__row_entity(one_row)
 
-    def get_cache_entity_by_id(self, primary_key_id, dependency_key='', cache_expire=600):
+    def get_cache_entity_by_id(self, primary_key_id, dependency_key='', cache_expire=1800):
         """
         :Description: 根据主键值获取实体对象
         :param primary_key_id: 主键ID值
@@ -324,7 +327,7 @@ class CacheModel(BaseModel):
             self.set_dependency_cache(dependency_key,cache_key,one_row,cache_expire)
             return self._BaseModel__row_entity(one_row)
 
-    def get_cache_total(self, where='', group_by='', field=None, params=None,dependency_key='', cache_expire=600):
+    def get_cache_total(self, where='', group_by='', field=None, params=None,dependency_key='', cache_expire=1800):
         """
         :Description: 根据条件获取数据数量
         :param where: 数据库查询条件语句
@@ -362,7 +365,7 @@ class CacheModel(BaseModel):
                 return list_row['count']
             return 0
 
-    def get_cache_dict(self, where='', group_by='', order_by='', limit='1', field="*", params=None, dependency_key='', cache_expire=600):
+    def get_cache_dict(self, where='', group_by='', order_by='', limit='1', field="*", params=None, dependency_key='', cache_expire=1800):
         """
         :Description: 返回字典dict
         :param dependencyKey: 依赖键
@@ -407,7 +410,7 @@ class CacheModel(BaseModel):
                     one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return one_row
 
-    def get_cache_dict_by_id(self, primary_key_id, dependency_key='', cache_expire=600, field="*"):
+    def get_cache_dict_by_id(self, primary_key_id, dependency_key='', cache_expire=1800, field="*"):
         """
         :Description: 根据主键ID获取dict
         :param primary_key_id: 主键ID值
@@ -439,7 +442,7 @@ class CacheModel(BaseModel):
                     one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return one_row
 
-    def get_cache_dict_list(self, where='', group_by='', order_by='', limit='', field="*", params=None, dependency_key='',cache_expire=600):
+    def get_cache_dict_list(self, where='', group_by='', order_by='', limit='', field="*", params=None, dependency_key='',cache_expire=1800):
         """
         :Description: 返回字典列表dict list
         :param where: 数据库查询条件语句
@@ -482,7 +485,7 @@ class CacheModel(BaseModel):
                         one_row[field] = self._BaseModel__convert_field_type(one_row[field])
             return list_row
 
-    def get_cache_dict_page_list(self, field="*", page_index=0 ,page_size=20, where='', group_by='' ,order_by='' ,params=None, dependency_key='', cache_expire=600):
+    def get_cache_dict_page_list(self, field="*", page_index=0 ,page_size=20, where='', group_by='' ,order_by='' ,params=None, dependency_key='', cache_expire=1800):
         """
         :Description: 获取分页字典数据
         :param field: 查询字段 
