@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-07-21 09:33:47
+@LastEditTime: 2022-07-26 14:35:38
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -26,17 +26,6 @@ class AssetConsoleModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        sub_table_config_list = config.get_value("sub_table_config_list", {})
-        sub_table_config = sub_table_config_list.get("asset_log_tb", {"sub_count": 0, "sub_ways": 0})
-        sub_count = sub_table_config.get("sub_count", 0)
-        if sub_count == 0:
-            y = threading.Thread(target=self._process_user_asset_warn, args=[None])
-            y.start()
-        else:
-            for i in range(sub_count):
-                 o = threading.Thread(target=self._process_user_asset_warn, args=[str(i)])
-                 o.start()
-
         for i in range(mod_count):
             j = threading.Thread(target=self._process_asset_inventory_warn, args=[i, mod_count])
             j.start()
@@ -47,65 +36,6 @@ class AssetConsoleModel():
         t = threading.Thread(target=self._process_asset_intercept_queue, args=[])
         t.start()
         
-    def _process_user_asset_warn(self, sub_table):
-        """
-        :description: 处理用户资产负数预警
-        :param sub_table: 分表名称
-        :return: 
-        :last_editors: HuangJianYi
-        """
-        print(f"{TimeHelper.get_now_format_time()} 用户资产负数预警启动")
-        while True:
-            try:
-                time.sleep(0.1)
-                asset_log_model = AssetLogModel(sub_table=sub_table)
-                asset_warn_notice_model = AssetWarnNoticeModel()
-                now_date = TimeHelper.get_now_format_time()
-                now_day_int = SevenHelper.get_now_day_int()
-                asset_log_list = asset_log_model.get_list(f"now_value<0 and {now_day_int}>warn_day ", order_by="create_date asc", limit="100")
-                if len(asset_log_list) > 0:
-                    for asset_log in asset_log_list:
-                        try:
-                            asset_log.warn_date = now_date
-                            asset_log.warn_day = now_day_int
-                            asset_log_model.update_entity(asset_log, "warn_date,warn_day")
-
-                            asset_warn_notice = AssetWarnNotice()
-                            asset_warn_notice.app_id = asset_log.app_id
-                            asset_warn_notice.act_id = asset_log.act_id
-                            asset_warn_notice.handler_name = asset_log.handler_name
-                            asset_warn_notice.request_code = asset_log.request_code
-                            asset_warn_notice.user_id = asset_log.user_id
-                            asset_warn_notice.open_id = asset_log.open_id
-                            asset_warn_notice.user_nick = asset_log.user_nick
-                            asset_warn_notice.asset_type = asset_log.asset_type
-                            asset_warn_notice.asset_object_id = asset_log.asset_object_id
-                            if asset_log.asset_type == 1:
-                                asset_warn_notice.log_title = "次数异常"
-                                asset_warn_notice.info_desc = f"值为负数:{asset_log.now_value}"
-                            elif asset_log.asset_type == 2:
-                                asset_warn_notice.log_title = "积分异常"
-                                asset_warn_notice.info_desc = f"值为负数:{asset_log.now_value}"
-                            elif asset_log.asset_type == 3:
-                                asset_warn_notice.log_title = f"价格档位异常"
-                                asset_warn_notice.info_desc = f"档位ID:{asset_log.asset_object_id},值为负数:{asset_log.now_value}"
-                            else:
-                                asset_warn_notice.log_title = f"资产类型：{asset_log.asset_type}异常"
-                                asset_warn_notice.info_desc = f"值为负数:{asset_log.now_value}"
-
-                            asset_warn_notice.info_json = SevenHelper.json_dumps(asset_log)
-                            asset_warn_notice.create_date = now_date
-                            asset_warn_notice.create_day = now_day_int
-                            asset_warn_notice_model.add_entity(asset_warn_notice)
-
-                        except Exception as ex:
-                            logger_error.error(f"用户资产负数预警异常,json串:{SevenHelper.json_dumps(asset_log)},ex:{traceback.format_exc()}")
-                            continue
-                else:
-                    time.sleep(1)
-            except Exception as ex:
-                time.sleep(5)
-
     def _process_onlyid_warn(self):
         """
         :description: 处理唯一值并发预警
@@ -215,7 +145,7 @@ class AssetConsoleModel():
                 if mod_count == 1:
                     asset_inventory_list = asset_inventory_model.get_list(f"create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="100")
                 else:
-                    asset_inventory_list = asset_inventory_model.get_list(f"MOD(user_id,{mod_count})={mod_value} and create_day={now_day_int} and process_count=0", order_by="create_date asc", limit="100")
+                    asset_inventory_list = asset_inventory_model.get_list(f"create_day={now_day_int} and process_count=0 and MOD(user_id,{mod_count})={mod_value}", order_by="create_date asc", limit="100")
                 if len(asset_inventory_list) > 0:
                     for asset_inventory in asset_inventory_list:
                         try:
@@ -289,7 +219,7 @@ class AssetConsoleModel():
                     operate_value = asset_queue_dict["operate_value"]
                     history_asset_value = asset_queue_dict["history_asset_value"]
                     asset_inventory_id_md5 = CryptoHelper.md5_encrypt_int(f"{act_id}_{user_id}_{asset_type}_{asset_object_id}_{now_day_int}")
-                    asset_inventory = asset_inventory_model.get_cache_entity("id_md5=%s",params=[asset_inventory_id_md5])
+                    asset_inventory = asset_inventory_model.get_entity("id_md5=%s",params=[asset_inventory_id_md5])
                     asset_inventory_update_sql = f"process_count=0,now_value={now_value}"
                     if asset_inventory:
                         old_asset_inventory_id = asset_inventory.id
