@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-11 09:10:33
-@LastEditTime: 2022-08-16 14:00:33
+@LastEditTime: 2022-11-28 13:37:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -236,21 +236,27 @@ class FrameBaseModel():
                 redis_init.expire(count_key, 24*60*60)
         return invoke_result_data
     
-    def check_act_info(self, act_id):
+    def check_act_info(self, act_id, check_release=True):
         """
         :description: 检验活动信息
         :param act_id:活动标识
+        :param check_release:校验活动信息发布
         :return:invoke_result_data
         :last_editors: HuangJianYi
         """
         invoke_result_data = InvokeResultData()
         act_info_model = ActInfoModel(context=self.context)
         act_info_dict = act_info_model.get_cache_dict_by_id(act_id,dependency_key=DependencyKey.act_info(act_id))
-        if not act_info_dict or act_info_dict["is_release"] == 0 or act_info_dict["is_del"] == 1:
+        if not act_info_dict or act_info_dict["is_del"] == 1:
             invoke_result_data.success = False
             invoke_result_data.error_code = "no_act"
             invoke_result_data.error_message = "活动信息不存在"
             return invoke_result_data
+        if check_release == True and act_info_dict["is_release"] == 0:
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "no_act"
+            invoke_result_data.error_message = "活动已下架"
+            return invoke_result_data
         now_date = SevenHelper.get_now_datetime()
         act_info_dict["start_date"] = str(act_info_dict["start_date"])
         act_info_dict["end_date"] = str(act_info_dict["end_date"])
@@ -269,10 +275,11 @@ class FrameBaseModel():
         invoke_result_data.data = act_info_dict
         return invoke_result_data
 
-    def check_act_module(self, module_id):
+    def check_act_module(self, module_id, check_release=True):
         """
         :description: 检验活动模块
         :param module_id:活动模块标识
+        :param check_release:校验活动信息发布
         :return:invoke_result_data
         :last_editors: HuangJianYi
         """
@@ -280,11 +287,16 @@ class FrameBaseModel():
         if module_id:
             act_module_model = ActModuleModel(context=self.context)
             act_module_dict = act_module_model.get_cache_dict_by_id(module_id,dependency_key=DependencyKey.act_module(module_id))
-            if not act_module_dict or act_module_dict["is_release"] == 0 or act_module_dict["is_del"] == 1:
+            if not act_module_dict or act_module_dict["is_del"] == 1:
                 invoke_result_data.success = False
                 invoke_result_data.error_code = "no_module"
                 invoke_result_data.error_message = "活动模块信息不存在"
                 return invoke_result_data
+            if check_release == True and act_module_dict["is_release"] == 0:
+                invoke_result_data.success = False
+                invoke_result_data.error_code = "no_module"
+                invoke_result_data.error_message = "活动模块已下架"
+                return invoke_result_data
             now_date = SevenHelper.get_now_datetime()
             act_module_dict["start_date"] = str(act_module_dict["start_date"])
             act_module_dict["end_date"] = str(act_module_dict["end_date"])
@@ -373,7 +385,7 @@ class FrameBaseModel():
             SevenHelper.redis_lpush(request_queue_name,user_id,request_limit_time)
         return invoke_result_data
     
-    def business_process_executing(self, app_id, act_id, module_id, user_id, login_token, handler_name, check_new_user=False, check_user_nick=True, continue_request_expire=5, acquire_lock_name="", request_limit_num=0, request_limit_time=1, source_object_id="",check_act_info=True,check_act_module=True,check_user_info=True):
+    def business_process_executing(self, app_id, act_id, module_id, user_id, login_token, handler_name, check_new_user=False, check_user_nick=True, continue_request_expire=5, acquire_lock_name="", request_limit_num=0, request_limit_time=1, source_object_id="",check_act_info=True,check_act_module=True,check_user_info=True,check_act_info_release=True,check_act_module_release=True):
         """
         :description: 业务执行前事件,核心业务如抽奖、做任务需要调用当前方法
         :param app_id:应用标识
@@ -392,6 +404,8 @@ class FrameBaseModel():
         :param check_act_info:是否检验活动信息
         :param check_act_module:是否检验活动模块信息
         :param check_user_info:是否校验用户信息
+        :param check_act_info_release:校验活动信息是否发布
+        :param check_act_module_release:校验活动模块是否发布
         :return:
         :last_editors: HuangJianYi
         """
@@ -416,7 +430,7 @@ class FrameBaseModel():
         #校验活动
         act_info_dict = None
         if check_act_info == True:
-            invoke_result_data = self.check_act_info(act_id)
+            invoke_result_data = self.check_act_info(act_id,check_act_info_release)
             if invoke_result_data.success == False:
                 return invoke_result_data
             act_info_dict = invoke_result_data.data
@@ -424,7 +438,7 @@ class FrameBaseModel():
         #校验活动模块
         act_module_dict = None
         if check_act_module == True:
-            invoke_result_data = self.check_act_module(module_id)
+            invoke_result_data = self.check_act_module(module_id,check_act_module_release)
             if invoke_result_data.success == False:
                 return invoke_result_data
             act_module_dict = invoke_result_data.data
