@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-02 15:17:41
-@LastEditTime: 2022-09-28 11:56:59
+@LastEditTime: 2022-12-01 16:35:02
 @LastEditors: HuangJianYi
 :description: 自定义实体模型
 """
@@ -421,4 +421,4 @@ class DependencyKey():
         :return str
         :last_editors: HuangJianYi
         """
-        f"user_black:{act_id}_{user_id}"
\ No newline at end of file
+        return f"user_black:{act_id}_{user_id}"
\ No newline at end of file
