@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2022-11-18 17:00:10
+@LastEditTime: 2022-11-24 19:09:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -448,6 +448,8 @@ class StatBaseModel(FrameBaseModel):
                 stat_queue.open_id = open_id
                 stat_queue.key_name = item["key"]
                 stat_queue.key_value = item["value"]
+                if hasattr(self.context, "request_code"):
+                    stat_queue.request_code = self.context.request_code
                 stat_queue.create_date = SevenHelper.get_now_datetime()
                 stat_queue.process_date = SevenHelper.get_now_datetime()
                 stat_queue_list.append(stat_queue)
@@ -461,6 +463,8 @@ class StatBaseModel(FrameBaseModel):
                 stat_queue.open_id = open_id
                 stat_queue.key_name = key
                 stat_queue.key_value = value
+                if hasattr(self.context, "request_code"):
+                    stat_queue.request_code = self.context.request_code
                 stat_queue.create_date = SevenHelper.get_now_datetime()
                 stat_queue.process_date = SevenHelper.get_now_datetime()
                 stat_queue_list.append(stat_queue)
