@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-08-12 09:06:24
-@LastEditTime: 2022-07-27 15:26:36
+@LastEditTime: 2022-10-13 12:39:02
 @LastEditors: HuangJianYi
 :description: 淘宝top接口基础类
 """
@@ -21,7 +21,7 @@ class TopBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def instantiate(self, app_id, user_nick, access_token, app_key, app_secret, is_log=False):
+    def instantiate(self, app_id, user_nick, access_token, app_key, app_secret, is_log=False, main_user_open_id=''):
         """
         :description: 实例化
         :param app_id:应用标识
@@ -79,16 +79,20 @@ class TopBaseModel():
         dead_date = invoke_result_data.data
         project_code = self.get_project_code(store_user_nick,access_token, app_key, app_secret, is_log)
         if app_info:
+            if main_user_open_id !="" and app_info.main_user_open_id == "":
+                app_info.main_user_open_id = main_user_open_id
             if dead_date != "expire":
                 app_info.expiration_date = dead_date
             if project_code != "":
                 if project_code != app_info.project_code:
                     is_change_project_code = True
                 app_info.project_code = project_code
-            invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+            # invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+            invoke_result_data = self.get_shop(access_token, app_key, app_secret, is_log)
             if invoke_result_data.success == True:
                 app_info.access_token = access_token
-            app_info_model.update_entity(app_info, "expiration_date,project_code,access_token")
+            app_info_model.update_entity(app_info, "main_user_open_id,expiration_date,project_code,access_token")
+            app_info_model.delete_dependency_key(DependencyKey.app_info(app_info.app_id))
             invoke_result_data.data = {"app_id": app_info.app_id, "store_user_nick": app_info.store_user_nick, "user_nick": user_nick, "access_token": app_info.access_token,"is_change_project_code":is_change_project_code}
             return invoke_result_data
 
@@ -98,20 +102,26 @@ class TopBaseModel():
         #     invoke_result_data.error_message = "对不起，初次创建活动包含实例化，请使用主账号进行创建。"
         #     return invoke_result_data
 
-        invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+        # invoke_result_data = self.get_goods_list(0, 1, "", "", "", access_token, app_key, app_secret)
+        # if invoke_result_data.success == False:
+        #     invoke_result_data.error_code = "account_error"
+        #     invoke_result_data.error_message = "对不起，请使用主账号或者授权的子账号进行创建"
+        #     return invoke_result_data
+        
+        invoke_result_data = self.get_shop(access_token, app_key, app_secret, is_log)
         if invoke_result_data.success == False:
-            invoke_result_data.error_code = "account_error"
-            invoke_result_data.error_message = "对不起，请使用主账号或者授权的子账号进行创建"
+            if invoke_result_data.error_code == "no_power":
+                invoke_result_data.error_code = "account_error"
+                invoke_result_data.error_message = "对不起，初次创建活动包含实例化，请使用主账号进行创建。"
             return invoke_result_data
+
+        shop_info = invoke_result_data.data if invoke_result_data.success == True else {}
+
         try:
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappTemplateInstantiateRequest()
-            req.clients = "taobao,tmall"
+            req.clients = config.get_value("instantiate_clients","taobao,tmall")
             req.description = description
-
-            invoke_result_data = self.get_shop(access_token, app_key, app_secret, is_log)
-            shop_info = invoke_result_data.data if invoke_result_data.success == True else {}
-
             req.ext_json = "{ \"name\":\"" + app_name + "\"}"
             req.icon = icon
             req.alias = app_name
@@ -119,7 +129,7 @@ class TopBaseModel():
             req.template_version = template_version
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【小程序实例化】"
+                log_info = str(resp) + "【access_token】：" + access_token + "【小程序实例化】" + SevenHelper.json_dumps(req)
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -141,6 +151,7 @@ class TopBaseModel():
             app_info.access_token = access_token
             app_info.expiration_date = dead_date
             app_info.project_code = project_code
+            app_info.main_user_open_id = main_user_open_id
 
             if "shop_seller_get_response" in shop_info.keys():
                 app_info.store_name = shop_info["shop_seller_get_response"]["shop"]["title"]
@@ -200,13 +211,13 @@ class TopBaseModel():
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappTemplateUpdateappRequest()
 
-            req.clients = "taobao,tmall"
+            req.clients = config.get_value("instantiate_clients","taobao,tmall")
             req.app_id = app_id
             req.template_id = client_template_id
             req.template_version = client_ver
             resp = req.getResponse(access_token)
             if is_log:
-                log_info = str(resp) + "【access_token】：" + access_token + "【app更新】"
+                log_info = str(resp) + "【access_token】：" + access_token + "【app更新】" + SevenHelper.json_dumps(req)
                 if self.context:
                     self.context.logging_link_info(log_info)
                 elif self.logging_link_info:
@@ -416,10 +427,10 @@ class TopBaseModel():
                         return invoke_result_data
             return invoke_result_data
 
-    def get_refund_order_list(self, buyer_nick, access_token, app_key, app_secret, start_modified="", end_modified="", page_size=50, is_log=False, open_id=""):
+    def get_refund_order_list(self, open_id, access_token, app_key, app_secret, start_modified="", end_modified="", page_size=50, is_log=False):
         """
         :description: 获取淘宝退款订单
-        :param buyer_nick：用户昵称
+        :param open_id：open_id
         :param access_token：access_token
         :param app_key:app_key
         :param app_secret:app_secret
@@ -427,7 +438,6 @@ class TopBaseModel():
         :param end_modified：结束时间
         :param page_size：页大小
         :param is_log：是否记录返回信息
-        :param open_id：open_id
         :return InvokeResultData
         :last_editors: HuangJianYi
         """
@@ -441,8 +451,6 @@ class TopBaseModel():
             # refund_id：退款单号, tid：淘宝交易单号, oid：子订单号, title：商品名称 , total_fee：订单总价, status：退款状态,
             # created：退款申请时间, refund_fee：退款金额, modified：更新时间, num: 购买数量
             req.type = "fixed"
-            if buyer_nick:
-                req.buyer_nick = buyer_nick
             req.page_size = page_size
             req.page_no = 1
             req.use_has_next = "true"
@@ -508,7 +516,7 @@ class TopBaseModel():
             top.setDefaultAppInfo(app_key, app_secret)
             req = top.api.MiniappTemplateOnlineappRequest()
 
-            req.clients = "taobao,tmall"
+            req.clients = config.get_value("instantiate_clients","taobao,tmall")
             req.app_id = app_id
             req.template_id = template_id
             req.template_version = template_version
